@@ -126,9 +126,10 @@ def _value(value):
         elif _v in ['none','null']:
             value=None
         elif _is_list_str(value):
-            value=value.split(',')
-            if value[-1] is '':
-                value=value[:-1]
+            value=value.split(':')
+            value=[_relist(v) for v in value]
+            if len(value)==1:
+                value=value[0]
         else:
             value=float(value)
             if (value==value//1): 
@@ -138,6 +139,13 @@ def _value(value):
     return value
 
 
+def _relist(value):
+    value=value.split(',')
+    if value[-1] is '':
+        value=value[:-1]
+    return value
+
+
 def _is_list_str(value):
     if (',' in value) and (' ' not in value):
         return True
